@@ -77,6 +77,40 @@ test_tuner_successive_halving = function(n, eta, learner, measures = msr("classi
     instance
 }
 
+#' @title Test Tuner Async Successive Halving
+#'
+#' @noRd
+#'
+#' @description
+#' Tests budget and number of configs constructed by the tuner against supplied bounds
+test_tuner_async_successive_halving = function(eta, learner, measures = msr("classif.ce"), sampler = NULL, n_workers = 2) {
+  flush_redis()
+  mirai::daemons(n_workers)
+  rush::rush_plan(n_workers = n_workers, worker_type = "remote")
+
+  search_space = learner$param_set$search_space()
+  budget_id = search_space$ids(tags = "budget")
+  r_min = search_space$lower[[budget_id]]
+  r_max = search_space$upper[[budget_id]]
+
+  instance = tune(
+    tnr("async_successive_halving", eta = eta, sampler = sampler),
+    task = tsk("pima"),
+    learner = learner,
+    measures = measures,
+    resampling = rsmp("cv", folds = 5),
+    terminator = trm("evals", n_evals = 20))
+
+
+  budget = as.data.table(instance$archive)[, budget_id, with = FALSE]
+
+  # check bounds of budget
+  expect_lte(max(budget), r_max)
+  expect_gte(min(budget), r_min)
+
+  instance
+}
+
 #' @title MeasureClassifBudget
 #'
 #' @noRd
@@ -105,3 +139,20 @@ MeasureClassifDummy = R6Class("MeasureClassifDummy",
 )
 
 mlr_measures$add("dummy", MeasureClassifDummy)
+
+expect_rush_reset = function(rush, type = "kill") {
+  rush$reset(type = type)
+  Sys.sleep(1)
+  keys = rush$connector$command(c("KEYS", "*"))
+  if (!test_list(keys, len = 0)) {
+    stopf("Found keys in redis after reset: %s", keys)
+  }
+  mirai::daemons(0)
+}
+
+flush_redis = function() {
+  config = redux::redis_config()
+  r = redux::hiredis(config)
+  r$FLUSHDB()
+}
+
